package com.ynet.life.sujrb.action;

import com.thoughtworks.xstream.XStream;
import com.thoughtworks.xstream.core.util.QuickWriter;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.thoughtworks.xstream.io.xml.PrettyPrintWriter;
import com.thoughtworks.xstream.io.xml.XppDriver;
import com.ynet.gene.log.GENELog;
import com.ynet.life.base.Trace;
import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.Reader;
import java.io.Writer;
import java.net.ConnectException;
import java.net.HttpURLConnection;
import java.net.URL;
import java.text.SimpleDateFormat;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import javax.net.ssl.HttpsURLConnection;
import javax.servlet.ServletInputStream;
import javax.servlet.http.HttpServletRequest;
import org.dom4j.Document;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;
import org.json.JSONObject;

/* loaded from: com_ynet_life_sujrb_action.jar:com/ynet/life/sujrb/action/MessageUtil.class */
public class MessageUtil {
    public static final String RESP_MESSAGE_TYPE_TEXT = "text";
    public static final String RESP_MESSAGE_TYPE_MUSIC = "music";
    public static final String RESP_MESSAGE_TYPE_NEWS = "news";
    public static final String REQ_MESSAGE_TYPE_TEXT = "text";
    public static final String REQ_MESSAGE_TYPE_IMAGE = "image";
    public static final String REQ_MESSAGE_TYPE_LINK = "link";
    public static final String REQ_MESSAGE_TYPE_LOCATION = "location";
    public static final String REQ_MESSAGE_TYPE_VOICE = "voice";
    public static final String REQ_MESSAGE_TYPE_EVENT = "event";
    public static final String EVENT_TYPE_SUBSCRIBE = "subscribe";
    public static final String EVENT_TYPE_UNSUBSCRIBE = "unsubscribe";
    public static final String EVENT_TYPE_CLICK = "CLICK";
    private static MessageUtil messageUtil;
    private static String send_message_url = "https://api.weixin.qq.com/cgi-bin/message/template/send?access_token=ACCESS_TOKEN";
    private static String upload_media_url = "http://file.api.weixin.qq.com/cgi-bin/media/upload?access_token=ACCESS_TOKEN&type=TYPE";
    private static String upload_article_url = "https://api.weixin.qq.com/cgi-bin/media/uploadnews?access_token=ACCESS_TOKEN";
    private static String message_openid_url = "https://api.weixin.qq.com/cgi-bin/message/mass/send?access_token=ACCESS_TOKEN";
    private static XStream xstream = new XStream(new XppDriver() { // from class: com.ynet.life.sujrb.action.MessageUtil.1
        public HierarchicalStreamWriter createWriter(Writer out) {
            return new PrettyPrintWriter(out) { // from class: com.ynet.life.sujrb.action.MessageUtil.1.1
                boolean cdata = true;

                public void startNode(String name, Class clazz) {
                    super.startNode(name, clazz);
                    if (name.equals("CreateTime")) {
                        this.cdata = false;
                    }
                }

                protected void writeText(QuickWriter writer, String text) {
                    if (this.cdata) {
                        writer.write("<![CDATA[");
                        writer.write(text);
                        writer.write("]]>");
                        return;
                    }
                    writer.write(text);
                }
            };
        }
    });

    private MessageUtil() {
    }

    public static MessageUtil getInstance() {
        if (messageUtil == null) {
            messageUtil = new MessageUtil();
        }
        return messageUtil;
    }

    public Map<String, String> parseXml(HttpServletRequest request) throws Exception {
        Map<String, String> map = new HashMap<>();
        ServletInputStream inputStream = request.getInputStream();
        Document document = new SAXReader().read(inputStream);
        String requestXml = document.asXML();
        String subXml = String.valueOf(requestXml.split(">")[0]) + ">";
        String requestXml2 = requestXml.substring(subXml.length());
        for (Element e : document.getRootElement().elements()) {
            map.put(e.getName(), e.getText());
        }
        map.put("requestXml", requestXml2);
        inputStream.close();
        return map;
    }

    public String parseMsgXml(HttpServletRequest request) {
        ServletInputStream servletInputStream = null;
        String responseMsg = null;
        try {
            ServletInputStream inputStream = request.getInputStream();
            byte[] jsonBytes = new byte[inputStream.available()];
            inputStream.read(jsonBytes);
            responseMsg = new String(jsonBytes, "UTF-8");
            servletInputStream = inputStream;
            servletInputStream.close();
        } catch (Exception e) {
            servletInputStream.printStackTrace();
        }
        return responseMsg;
    }

    public static String textMessageToXml(TextMessage textMessage) {
        xstream.alias("xml", textMessage.getClass());
        return xstream.toXML(textMessage);
    }

    public static String newsMessageToXml(NewsMessage newsMessage) {
        xstream.alias("xml", newsMessage.getClass());
        xstream.alias("item", new Article().getClass());
        return xstream.toXML(newsMessage);
    }

    public static JSONObject getConnection(String Url) throws Exception {
        HttpURLConnection connection = (HttpURLConnection) new URL(Url).openConnection();
        connection.setRequestMethod("GET");
        connection.setDoOutput(true);
        connection.setDoInput(true);
        connection.connect();
        InputStream inputStream = connection.getInputStream();
        byte[] bs = new byte[inputStream.available()];
        inputStream.read(bs);
        String message = new String(bs, "UTF-8");
        return new JSONObject(message);
    }

    public static String getPciValue(String pciStt) {
        String message = "";
        if ("2".equals(pciStt)) {
            message = "市政府部门审核中";
        } else if ("4".equals(pciStt)) {
            message = "市政府部门审核不通过";
        } else if ("5".equals(pciStt)) {
            message = "请完善信息";
        } else if ("0".equals(pciStt)) {
            message = "市政府部门审核通过";
        }
        return message;
    }

    public static String getValueByProperties(String reqStt, String properties) throws IOException {
        Properties props = new Properties();
        InputStream inStream = MessageUtil.class.getClassLoader().getResourceAsStream(properties);
        Reader reader = new InputStreamReader(inStream, "utf-8");
        props.load(reader);
        return props.get(reqStt).toString();
    }

    public static Map<String, String> getBranchMap() {
        Map<String, String> map = new HashMap<>();
        map.put("00000001", "苏州银行");
        map.put("00000002", "招商银行");
        map.put("00000003", "光大银行");
        map.put("00000004", "交通银行");
        map.put("00000005", "中国银行");
        map.put("00000006", "华夏银行");
        map.put("00000007", "建设银行");
        map.put("00000008", "人保产险");
        map.put("00000009", "太保产险");
        map.put("00000010", "信用再担保");
        map.put("00000011", "江苏银行");
        map.put("00000012", "民生银行");
        map.put("00000013", "宁波银行");
        map.put("00000014", "常熟农商行");
        map.put("00000015", "农业银行");
        map.put("00000016", "广发银行");
        map.put("00000017", "上海银行");
        map.put("00000018", "工商银行");
        map.put("00000019", "中国邮政储蓄银行苏州分行");
        map.put("00000020", "太仓农商行");
        map.put("00000021", "浦发银行");
        map.put("00000022", "渣打银行");
        map.put("00000023", "泰隆银行");
        map.put("00000024", "吴江农商行");
        map.put("00000025", "兴业银行");
        map.put("00000026", "昆山农商行");
        map.put("00000027", "吴中珠江村镇银行");
        map.put("00000028", "张家港农商行");
        map.put("00000029", "中信银行");
        map.put("00000030", "南京银行");
        map.put("00000031", "江西银行");
        map.put("00000032", "恒丰银行");
        map.put("00000033", "苏金租赁");
        map.put("00000034", "张家港市农业担保有限公司");
        map.put("00000035", "苏州市苏园担保有限公司");
        map.put("00000800", "苏州金融资产交易中心");
        map.put("00000900", "苏金租赁");
        map.put("00001001", "平安产险");
        map.put("00001003", "中银保险");
        map.put("00001014", "农业担保");
        map.put("00001016", "高新区中小担保");
        map.put("00001017", "信用再担保");
        map.put("00001019", "国发担保");
        map.put("00001021", "天安财险");
        map.put("00001026", "太平财险");
        map.put("00001027", "人寿财险");
        map.put("00001033", "太仓市担保有限公司");
        map.put("00001034", "苏州高新区新合盛担保有限公司");
        map.put("00001035", "江苏省信用再担保有限公司");
        map.put("00001036", "吴江创融中小企业担保有限公司");
        map.put("00001037", "苏州市吴中城乡农业担保有限公司");
        map.put("00001038", "中华联合财险苏州中支公司");
        map.put("00001039", "浙商银行");
        map.put("00001040", "紫金财产保险股份有限公司苏州分公司");
        return map;
    }

    public static Map<String, String> getReqMap() {
        Map<String, String> map = new HashMap<>();
        map.put("10", "关注");
        map.put("11", "取消关注");
        map.put("12", "关注超时");
        map.put("13", "审核通过");
        map.put("14", "审核通过");
        map.put("15", "审核修改");
        map.put("20", "启动审核");
        map.put("21", "审核通过");
        map.put("22", "审核不通过");
        map.put("23", "审核超时");
        map.put("24", "担保审核未确认");
        map.put("25", "担保审核通过");
        map.put("26", "担保审核拒绝");
        map.put("27", "审核通过");
        map.put("28", "启动审核修改");
        map.put("29", "担保审核修改");
        map.put("30", "授信");
        map.put("301", "一般业务审核通过");
        map.put("302", "一般业务审核修改");
        map.put("303", "一般业务审核拒绝");
        map.put("31", "授信修改");
        map.put("33", "授信拒绝");
        map.put("34", "放款申请修改");
        map.put("35", "发起放款申请");
        map.put("36", "担保放款申请通过");
        map.put("37", "再担保放款申请通过");
        map.put("38", "担保放款申请拒绝");
        map.put("39", "再担保放款申请拒绝");
        map.put("40", "放款");
        map.put("41", "放款修改");
        map.put("42", "担保放款申请修改");
        map.put("43", "再担保放款申请修改");
        map.put("45", "放款拒绝");
        map.put("50", "撤销");
        map.put("60", "放款备案");
        map.put("70", "放款备案确认通过");
        map.put("71", "放款备案确认拒绝");
        map.put("80", "还款");
        map.put("81", "还款备案确认通过");
        map.put("82", "还款备案确认拒绝");
        map.put("83", "逾期");
        map.put("84", "续贷");
        map.put("85", "还款推送");
        map.put("88", "还款修改");
        map.put("90", "还款还清");
        map.put("54", "撮合失败");
        map.put("55", "撮合成功");
        map.put("56", "无效需求");
        return map;
    }

    public static boolean isRejectOpstt(String opStt) {
        boolean isReject;
        if ("22".equals(opStt) || "26".equals(opStt) || "303".equals(opStt) || "33".equals(opStt) || "38".equals(opStt) || "39".equals(opStt) || "45".equals(opStt) || "71".equals(opStt) || "82".equals(opStt)) {
            isReject = true;
        } else {
            isReject = false;
        }
        return isReject;
    }

    public static String getRegisterMessage(String pciName, String orgCode, String pciStt, String refuse) {
        String pciName2;
        if ("4".equals(pciStt)) {
            pciName2 = "请以注册时填写的用户名及密码登录系统，并根据失败原因处理并再次提交审核。如有疑问请拨打电话：0512-57920990！ ";
        } else if ("3".equals(pciStt)) {
            pciName2 = "您可以登录平台进行申请进度查询。如有疑问请拨打电话：0512-57920990！ ";
        } else if ("6".equals(pciStt)) {
            pciName2 = "请以注册时填写的用户名及密码登录系统，并根据失败原因处理并再次提交审核。如有疑问请拨打电话：0512-57920990！ ";
        } else if ("0".equals(pciStt)) {
            pciName2 = "您可以登录平台发布需求。如有疑问请拨打电话：0512-57920990！ ";
        } else {
            pciName2 = String.valueOf(pciName) + "，您已成为平台用户，您的用户名：" + orgCode + "，请耐心等待市政府部门的审核。您可以登录平台对注册进度查询。如有疑问请拨打电话0512-57920990！";
        }
        return pciName2;
    }

    public static String getDateFormat(String dateString) {
        SimpleDateFormat myFmt1 = new SimpleDateFormat("yyyyMMdd");
        SimpleDateFormat myFmt2 = new SimpleDateFormat("yyyy年MM月dd日");
        Date date = null;
        try {
            date = myFmt1.parse(dateString);
        } catch (Exception ex) {
            Trace.logError("LifeAction", "日期格式转换错误", ex);
        }
        return myFmt2.format(date);
    }

    public static String getNewAccessToken() {
        String token = null;
        JSONObject jsonObject = httpRequest("https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid=APPID&secret=APPSECRET".replace("APPID", "wx64628067f2386ee0").replace("APPSECRET", "9b9707db2cdeff8cff53302d75c0abbd"), "GET", null);
        if (jsonObject != null) {
            try {
                token = jsonObject.getString("access_token");
            } catch (Exception unused) {
                token = null;
            }
        }
        return token;
    }

    public static void sendMessageByModel(JSONObject obj) throws Exception {
        String accesstoken = getNewAccessToken();
        String requestUrl = send_message_url.replace("ACCESS_TOKEN", accesstoken);
        try {
            GENELog.log("【微信模块】", GENELog.INFO, 0, "微信请求数据：" + obj.toString());
            GENELog.log("【微信模块】", GENELog.ERROR, 0, "微信请求数据：" + obj.toString());
            System.out.println("微信请求数据：" + obj.toString());
            JSONObject result = httpRequest(requestUrl, "POST", obj.toString());
            GENELog.log("【微信模块】", GENELog.INFO, 0, "微信返回的结果======：" + result.toString());
            System.out.println("微信返回的结果======：" + result.toString());
        } catch (Exception e) {
            throw new Exception(e);
        }
    }

    public static void sendMessageToOpenidsWithArticles(List<String> openids, List<Article> articles) throws Exception {
        String accesstoken = getNewAccessToken();
        String requestUrl = message_openid_url.replace("ACCESS_TOKEN", accesstoken);
        try {
            JSONObject obj = new JSONObject();
            JSONObject mpnews = new JSONObject();
            String mediaId = uploadArticles(accesstoken, articles).getString("media_id");
            obj.put("touser", (Collection) openids);
            mpnews.put("media_id", mediaId);
            obj.put("mpnews", mpnews);
            obj.put("msgtype", "mpnews");
            obj.put("send_ignore_reprint", 0);
            JSONObject result = httpRequest(requestUrl, "POST", obj.toString());
            System.out.println("微信返回的结果：" + result.toString());
        } catch (Exception e) {
            throw new Exception(e);
        }
    }

    public static JSONObject uploadMediaFile(String accesstoken, String filePath, String fileName, String type) throws Exception {
        JSONObject result = new JSONObject();
        if (accesstoken != null) {
            String requestUrl = upload_media_url.replace("ACCESS_TOKEN", accesstoken).replace("TYPE", type);
            File file = new File(String.valueOf(filePath) + fileName);
            JSONObject uploadMediaFile = uploadMediaFile(requestUrl, file, "image/jpeg");
            result = uploadMediaFile;
            if (uploadMediaFile.has("errcode")) {
                System.out.println("上传媒体资源失败！errcode=" + result.getString("errcode") + ",errmsg = " + result.getString("errmsg"));
            }
        }
        return result;
    }

    public static String getFileMediaId(String accesstoken, Article article) throws Exception {
        JSONObject response = uploadMediaFile(accesstoken, article.getFilePath(), article.getFileName(), "image/jpeg");
        if (response != null) {
            return response.getString("media_id");
        }
        throw new Exception("获取文件的media_id失败");
    }

    public static JSONObject uploadArticles(String accesstoken, List<Article> articles) throws Exception {
        String requestUrl = upload_article_url.replace("ACCESS_TOKEN", accesstoken);
        for (Article article : articles) {
            if (article.getFileName() != null && article.getFileName().length() > 0) {
                try {
                    String mediaId = getFileMediaId(accesstoken, article);
                    article.setThumb_media_id(mediaId);
                } catch (Exception e) {
                    throw new Exception(e);
                }
            }
        }
        JSONObject obj = new JSONObject();
        obj.put("articles", (Collection) articles);
        JSONObject result = httpRequest(requestUrl, "POST", obj.toString());
        System.out.println("微信返回的结果：" + result.toString());
        return result;
    }

    public static JSONObject httpRequest(String requestUrl, String requestMethod, String outputStr) {
        JSONObject jsonObject = null;
        StringBuffer buffer = new StringBuffer();
        try {
            HttpsURLConnection httpUrlConn = (HttpsURLConnection) new URL(requestUrl).openConnection();
            httpUrlConn.setDoOutput(true);
            httpUrlConn.setDoInput(true);
            httpUrlConn.setUseCaches(false);
            httpUrlConn.setRequestMethod(requestMethod);
            if ("GET".equalsIgnoreCase(requestMethod)) {
                httpUrlConn.connect();
            }
            if (outputStr != null) {
                OutputStream outputStream = httpUrlConn.getOutputStream();
                outputStream.write(outputStr.getBytes("UTF-8"));
                outputStream.close();
            }
            InputStream inputStream = httpUrlConn.getInputStream();
            InputStreamReader inputStreamReader = new InputStreamReader(inputStream, "utf-8");
            BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
            while (true) {
                String str = bufferedReader.readLine();
                if (str == null) {
                    break;
                }
                buffer.append(str);
            }
            bufferedReader.close();
            inputStreamReader.close();
            inputStream.close();
            httpUrlConn.disconnect();
            jsonObject = new JSONObject(buffer.toString());
        } catch (ConnectException unused) {
            System.out.println("Weixin server connection timed out.");
        } catch (Exception e) {
            System.out.println("https request error:{}" + e.getMessage());
        }
        return jsonObject;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v12, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v46, types: [org.json.JSONObject] */
    /* JADX WARN: Type inference failed for: r0v6 */
    public static JSONObject uploadMediaFile(String requestUrl, File file, String content_type) {
        JSONObject jsonObject = null;
        StringBuffer bufferStr = new StringBuffer();
        DataOutputStream dos = null;
        ?? r0 = 0;
        BufferedReader bufferedReader = null;
        try {
            try {
                HttpURLConnection conn = (HttpURLConnection) new URL(requestUrl).openConnection();
                conn.setDoInput(true);
                conn.setDoOutput(true);
                conn.setUseCaches(false);
                conn.setRequestMethod("POST");
                conn.setRequestProperty("Connection", "Keep-Alive");
                conn.setRequestProperty("Content-Type", "multipart/form-data;boundary=".concat(String.valueOf("*****")));
                DataOutputStream dataOutputStream = new DataOutputStream(conn.getOutputStream());
                dos = dataOutputStream;
                dataOutputStream.writeBytes(String.valueOf("--") + "*****\r\n");
                dos.writeBytes("Content-Disposition: form-data; name=\"" + file + "\";filename=\"" + file.getName() + ";Content-Type=\"" + content_type + "\r\n");
                dos.writeBytes("\r\n");
                BufferedInputStream bufin = new BufferedInputStream(new FileInputStream(file));
                byte[] buffer = new byte[8192];
                while (true) {
                    int count = bufin.read(buffer);
                    if (count == -1) {
                        break;
                    }
                    dos.write(buffer, 0, count);
                }
                bufin.close();
                dos.writeBytes("\r\n");
                dos.writeBytes(String.valueOf("--") + "*****--\r\n");
                dos.flush();
                InputStream inputStream = conn.getInputStream();
                InputStreamReader inputStreamReader = new InputStreamReader(inputStream, "utf-8");
                bufferedReader = new BufferedReader(inputStreamReader);
                while (true) {
                    String str = bufferedReader.readLine();
                    if (str == null) {
                        break;
                    }
                    bufferStr.append(str);
                }
                r0 = new JSONObject(bufferStr.toString());
                jsonObject = r0;
                try {
                    dos.close();
                    bufferedReader.close();
                } catch (Exception unused) {
                }
            } catch (Exception e) {
                r0.printStackTrace();
                System.out.println("与服务器连接发生异常错误:" + e.toString());
                System.out.println("连接地址是:".concat(String.valueOf(requestUrl)));
                if (dos != null) {
                    try {
                        dos.close();
                    } catch (Exception unused2) {
                    }
                }
                if (bufferedReader != null) {
                    bufferedReader.close();
                }
            }
            return jsonObject;
        } catch (Throwable th) {
            if (dos != null) {
                try {
                    dos.close();
                } catch (Exception unused3) {
                    throw th;
                }
            }
            if (bufferedReader != null) {
                bufferedReader.close();
            }
            throw th;
        }
    }
}
